@@ -9,7 +9,11 @@ __PACKAGE__->table("netmap_positions");
 __PACKAGE__->add_columns(
   "id",
   { data_type => "integer", is_nullable => 0, is_auto_increment => 1 },
-  "device_groups",
+  "device",
+  { data_type => "inet", is_nullable => 1 },
+  "host_groups",
+  { data_type => "text[]", is_nullable => 0 },
+  "locations",
   { data_type => "text[]", is_nullable => 0 },
   "vlan",
   { data_type => "integer", is_nullable => 0, default => 0 },
@@ -19,7 +23,4 @@ __PACKAGE__->add_columns(
 
 __PACKAGE__->set_primary_key("id");
 
-__PACKAGE__->add_unique_constraint(
-  "netmap_positions_device_groups_vlan_key" => [qw/device_groups vlan/]);
-
 1;
