@@ -66,7 +66,8 @@ sub arpnip {
     my @lines = split(m/\n/, $before);
 
 #   ? (192.168.17.178) at 5C:F9:DD:71:1F:08 [ether] on LAN1
-    my $linereg = qr/\?\s+\(([0-9\.]+)\)\s+at\s+([a-fA-F0-9:]+)/;
+# https://github.com/netdisco/netdisco/issues/365
+    my $linereg = qr/([0-9.]+)\s+ether\s+([a-fA-F0-9:]+).+/;
     foreach my $line (@lines) {
         if ($line =~ $linereg) {
             my ($ip, $mac) = ($1, $2);
